/* collection-view.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from collection-view.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libgd/gd.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesCollectionViewPrivate BoxesCollectionViewPrivate;

#define BOXES_TYPE_CATEGORY (boxes_category_get_type ())
#define BOXES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CATEGORY, BoxesCategory))
#define BOXES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CATEGORY, BoxesCategoryClass))
#define BOXES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CATEGORY))
#define BOXES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CATEGORY))
#define BOXES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CATEGORY, BoxesCategoryClass))

typedef struct _BoxesCategory BoxesCategory;
typedef struct _BoxesCategoryClass BoxesCategoryClass;

#define BOXES_COLLECTION_VIEW_TYPE_MODEL_COLUMNS (boxes_collection_view_model_columns_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) ((var == NULL) ? NULL : (var = (g_free (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block10Data Block10Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _Block11Data Block11Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _Block12Data Block12Data;
typedef struct _Block13Data Block13Data;
#define __vala_GdkEventMotion_free0(var) ((var == NULL) ? NULL : (var = (_vala_GdkEventMotion_free (var), NULL)))

#define BOXES_CATEGORY_TYPE_KIND (boxes_category_kind_get_type ())

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionView {
	GdMainView parent_instance;
	BoxesCollectionViewPrivate * priv;
};

struct _BoxesCollectionViewClass {
	GdMainViewClass parent_class;
};

struct _BoxesCollectionViewPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	BoxesCategory* _category;
	GtkListStore* store;
	GtkTreeModelFilter* model_filter;
	GtkTreeIter* prelight_iter;
};

typedef enum  {
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT = GD_MAIN_COLUMN_ICON,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE = GD_MAIN_COLUMN_PRIMARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO = GD_MAIN_COLUMN_SECONDARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED = GD_MAIN_COLUMN_SELECTED,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE = GD_MAIN_COLUMN_PULSE,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM = GD_MAIN_COLUMN_LAST,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST
} BoxesCollectionViewModelColumns;

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block10Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesMachine* machine;
	GtkTreeIter iter;
	BoxesCollectionItem* item;
};

struct _Block11Data {
	int _ref_count_;
	BoxesCollectionView* self;
	GList* selected;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _Block12Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesSelectionCriteria selection;
};

struct _Block13Data {
	int _ref_count_;
	BoxesCollectionView* self;
	gint pulse;
	BoxesMachine* machine;
};

typedef enum  {
	BOXES_CATEGORY_KIND_USER,
	BOXES_CATEGORY_KIND_NEW,
	BOXES_CATEGORY_KIND_FAVORITES,
	BOXES_CATEGORY_KIND_PRIVATE,
	BOXES_CATEGORY_KIND_SHARED
} BoxesCategoryKind;


static gpointer boxes_collection_view_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface* boxes_collection_view_boxes_ui_parent_iface = NULL;

GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_category_get_type (void) G_GNUC_CONST;
#define BOXES_COLLECTION_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewPrivate))
enum  {
	BOXES_COLLECTION_VIEW_DUMMY_PROPERTY,
	BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE,
	BOXES_COLLECTION_VIEW_UI_STATE,
	BOXES_COLLECTION_VIEW_CATEGORY
};
static GType boxes_collection_view_model_columns_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void boxes_collection_view_ui_state_changed (BoxesCollectionView* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
static gboolean _gtk_tree_iter_equal (const GtkTreeIter* s1, const GtkTreeIter* s2);
GdkPixbuf* boxes_machine_get_prelight_pixbuf (BoxesMachine* self);
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_add1 (GIcon*** array, int* length, int* size, GIcon* value);
static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result);
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
const gchar* boxes_machine_get_info (BoxesMachine* self);
static void __lambda68_ (Block10Data* _data10_);
static void ___lambda68__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda69_ (Block10Data* _data10_);
static void ___lambda69__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda70_ (Block10Data* _data10_);
static void ___lambda70__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda71_ (Block10Data* _data10_);
static void ___lambda71__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_view_setup_activity (BoxesCollectionView* self, GtkTreeIter* iter, BoxesMachine* machine);
static void __lambda73_ (Block10Data* _data10_);
static void ___lambda73__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
GType boxes_app_get_type (void) G_GNUC_CONST;
GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void block11_data_unref (void * _userdata_);
static gboolean __lambda74_ (Block11Data* _data11_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter);
static gboolean ___lambda74__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter);
static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path);
static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter);
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
gboolean boxes_collection_filter_filter (BoxesCollectionFilter* self, BoxesCollectionItem* item);
void boxes_collection_view_refilter (BoxesCollectionView* self);
void boxes_collection_view_activate_first_item (BoxesCollectionView* self);
static void boxes_collection_view_setup_view (BoxesCollectionView* self);
static gint __lambda75_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreeIter* a, GtkTreeIter* b);
gint boxes_collection_item_compare (BoxesCollectionItem* self, BoxesCollectionItem* other);
static gint ___lambda75__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self);
static void __lambda76_ (BoxesCollectionView* self);
static void ___lambda76__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self);
static void __lambda77_ (BoxesCollectionView* self);
static void ___lambda77__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self);
static void __lambda78_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
static void ___lambda78__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self);
static void __lambda79_ (BoxesCollectionView* self);
static void ___lambda79__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self);
static void __lambda80_ (BoxesCollectionView* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static void ___lambda80__gd_main_view_selection_mode_request (GdMainView* _sender, gpointer self);
static gboolean boxes_collection_view_on_motion_notify (BoxesCollectionView* self, GtkWidget* widget, GdkEvent* event);
static gboolean _boxes_collection_view_on_motion_notify_gtk_widget_motion_notify_event (GtkWidget* _sender, GdkEventMotion* event, gpointer self);
static gboolean boxes_collection_view_on_leave_notify (BoxesCollectionView* self, GtkWidget* widget, GdkEvent* event);
static gboolean _boxes_collection_view_on_leave_notify_gtk_widget_leave_notify_event (GtkWidget* _sender, GdkEventCrossing* event, gpointer self);
void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
static gboolean __lambda82_ (Block12Data* _data12_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter);
gboolean boxes_machine_is_running (BoxesMachine* self);
static gboolean ___lambda82__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static Block13Data* block13_data_ref (Block13Data* _data13_);
static void block13_data_unref (void * _userdata_);
gboolean boxes_machine_get_under_construction (BoxesMachine* self);
static gboolean __lambda72_ (Block13Data* _data13_);
static gboolean ___lambda72__gsource_func (gpointer self);
static GdkEventMotion* _vala_GdkEventMotion_copy (GdkEventMotion* self);
static gboolean __lambda81_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter);
static gboolean ___lambda81__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static void _vala_GdkEventMotion_free (GdkEventMotion* self);
BoxesCollectionView* boxes_collection_view_new (void);
BoxesCollectionView* boxes_collection_view_construct (GType object_type);
BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self);
void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value);
static GObject * boxes_collection_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType boxes_category_kind_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_category_new (const gchar* name, BoxesCategoryKind kind);
BoxesCategory* boxes_category_construct (GType object_type, const gchar* name, BoxesCategoryKind kind);
static void _boxes_collection_view_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_collection_view___lambda83_ (BoxesCollectionView* self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
static void __boxes_collection_view___lambda83__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_view_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType boxes_selection_criteria_get_type (void) {
	static volatile gsize boxes_selection_criteria_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selection_criteria_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SELECTION_CRITERIA_ALL, "BOXES_SELECTION_CRITERIA_ALL", "all"}, {BOXES_SELECTION_CRITERIA_NONE, "BOXES_SELECTION_CRITERIA_NONE", "none"}, {BOXES_SELECTION_CRITERIA_RUNNING, "BOXES_SELECTION_CRITERIA_RUNNING", "running"}, {0, NULL, NULL}};
		GType boxes_selection_criteria_type_id;
		boxes_selection_criteria_type_id = g_enum_register_static ("BoxesSelectionCriteria", values);
		g_once_init_leave (&boxes_selection_criteria_type_id__volatile, boxes_selection_criteria_type_id);
	}
	return boxes_selection_criteria_type_id__volatile;
}


static GType boxes_collection_view_model_columns_get_type (void) {
	static volatile gsize boxes_collection_view_model_columns_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_model_columns_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT", "screenshot"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE", "title"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO", "info"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED", "selected"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE", "pulse"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM", "item"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_collection_view_model_columns_type_id;
		boxes_collection_view_model_columns_type_id = g_enum_register_static ("BoxesCollectionViewModelColumns", values);
		g_once_init_leave (&boxes_collection_view_model_columns_type_id__volatile, boxes_collection_view_model_columns_type_id);
	}
	return boxes_collection_view_model_columns_type_id__volatile;
}


static void boxes_collection_view_ui_state_changed (BoxesCollectionView* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _tmp0_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == BOXES_UI_STATE_COLLECTION) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all ((GdMainView*) self);
#line 477 "collection-view.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? g_object_ref (self) : NULL;
#line 485 "collection-view.c"
}


static gboolean _gtk_tree_iter_equal (const GtkTreeIter* s1, const GtkTreeIter* s2) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (s1 == s2) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return TRUE;
#line 494 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (s1 == NULL) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return FALSE;
#line 500 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (s2 == NULL) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return FALSE;
#line 506 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (s1->stamp != s2->stamp) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return FALSE;
#line 512 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (s1->user_data != s2->user_data) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return FALSE;
#line 518 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (s1->user_data2 != s2->user_data2) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return FALSE;
#line 524 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (s1->user_data3 != s2->user_data3) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return FALSE;
#line 530 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return TRUE;
#line 534 "collection-view.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	for (i = 0; i < stack_length; i++) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return TRUE;
#line 546 "collection-view.c"
		}
	}
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return FALSE;
#line 551 "collection-view.c"
}


static void _vala_array_add1 (GIcon*** array, int* length, int* size, GIcon* value) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((*length) == (*size)) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*array = g_renew (GIcon*, *array, (*size) + 1);
#line 562 "collection-view.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[(*length)++] = value;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[*length] = NULL;
#line 568 "collection-view.c"
}


static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* item = NULL;
	GIcon** emblem_icons = NULL;
	GIcon** _tmp0_ = NULL;
	gint emblem_icons_length1 = 0;
	gint _emblem_icons_size_ = 0;
	GtkListStore* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesMachine* _tmp4_ = NULL;
	BoxesMachine* _tmp5_ = NULL;
	GdkPixbuf* _tmp6_ = NULL;
	GtkTreeIter _tmp7_ = {0};
	GtkTreeIter* _tmp8_ = NULL;
	GdkPixbuf* pixbuf = NULL;
	GdkPixbuf* _tmp15_ = NULL;
	BoxesMachine* _tmp16_ = NULL;
	BoxesBoxConfig* _tmp17_ = NULL;
	gchar** _tmp18_ = NULL;
	gint _tmp18__length1 = 0;
	gchar** _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	gchar** _tmp20_ = NULL;
	gint _tmp20__length1 = 0;
	gboolean _tmp21_ = FALSE;
	GIcon** _tmp24_ = NULL;
	gint _tmp24__length1 = 0;
	GtkListStore* _tmp54_ = NULL;
	GtkTreeIter _tmp55_ = {0};
	GdkPixbuf* _tmp56_ = NULL;
	GError * _inner_error_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = g_new0 (GIcon*, 0 + 1);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = _tmp0_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons_length1 = 0;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_emblem_icons_size_ = emblem_icons_length1;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->store;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = *iter;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp1_, &_tmp2_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine = _tmp4_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = *iter;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = self->priv->prelight_iter;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_gtk_tree_iter_equal (&_tmp7_, _tmp8_) == TRUE) {
#line 638 "collection-view.c"
		BoxesMachine* _tmp9_ = NULL;
		GdkPixbuf* _tmp10_ = NULL;
		GdkPixbuf* _tmp11_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp9_ = machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp10_ = boxes_machine_get_prelight_pixbuf (_tmp9_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = _tmp10_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp11_;
#line 650 "collection-view.c"
	} else {
		BoxesMachine* _tmp12_ = NULL;
		GdkPixbuf* _tmp13_ = NULL;
		GdkPixbuf* _tmp14_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp12_ = machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp13_ = boxes_machine_get_pixbuf (_tmp12_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp14_ = _tmp13_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp14_;
#line 663 "collection-view.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _g_object_ref0 (_tmp6_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf = _tmp15_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = machine;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = _tmp16_->config;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = boxes_box_config_get_categories (_tmp17_, &_tmp18__length1);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = _tmp18_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19__length1 = _tmp18__length1;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = _tmp19_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20__length1 = _tmp19__length1;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = _vala_string_array_contains (_tmp20_, _tmp19__length1, "favorite");
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = (_vala_array_free (_tmp20_, _tmp20__length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp21_) {
#line 689 "collection-view.c"
		GIcon** _tmp22_ = NULL;
		gint _tmp22__length1 = 0;
		GIcon* _tmp23_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp22_ = emblem_icons;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp22__length1 = emblem_icons_length1;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp23_ = boxes_create_symbolic_emblem ("emblem-favorite");
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_array_add1 (&emblem_icons, &emblem_icons_length1, &_emblem_icons_size_, _tmp23_);
#line 701 "collection-view.c"
	}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = emblem_icons;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24__length1 = emblem_icons_length1;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp24__length1 > 0) {
#line 709 "collection-view.c"
		GEmblemedIcon* emblemed_icon = NULL;
		GdkPixbuf* _tmp25_ = NULL;
		GEmblemedIcon* _tmp26_ = NULL;
		GIcon** _tmp27_ = NULL;
		gint _tmp27__length1 = 0;
		GtkIconTheme* theme = NULL;
		GtkIconTheme* _tmp33_ = NULL;
		GtkIconTheme* _tmp34_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp25_ = pixbuf;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp26_ = (GEmblemedIcon*) g_emblemed_icon_new ((GIcon*) _tmp25_, NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		emblemed_icon = _tmp26_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = emblem_icons;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27__length1 = emblem_icons_length1;
#line 728 "collection-view.c"
		{
			GIcon** emblem_icon_collection = NULL;
			gint emblem_icon_collection_length1 = 0;
			gint _emblem_icon_collection_size_ = 0;
			gint emblem_icon_it = 0;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection = _tmp27_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection_length1 = _tmp27__length1;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			for (emblem_icon_it = 0; emblem_icon_it < _tmp27__length1; emblem_icon_it = emblem_icon_it + 1) {
#line 740 "collection-view.c"
				GIcon* _tmp28_ = NULL;
				GIcon* emblem_icon = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp28_ = _g_object_ref0 (emblem_icon_collection[emblem_icon_it]);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				emblem_icon = _tmp28_;
#line 747 "collection-view.c"
				{
					GEmblemedIcon* _tmp29_ = NULL;
					GIcon* _tmp30_ = NULL;
					GEmblem* _tmp31_ = NULL;
					GEmblem* _tmp32_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp29_ = emblemed_icon;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp30_ = emblem_icon;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp31_ = g_emblem_new (_tmp30_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp32_ = _tmp31_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					g_emblemed_icon_add_emblem (_tmp29_, _tmp32_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (_tmp32_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (emblem_icon);
#line 767 "collection-view.c"
				}
			}
		}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp33_ = gtk_icon_theme_get_default ();
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp34_ = _g_object_ref0 (_tmp33_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		theme = _tmp34_;
#line 777 "collection-view.c"
		{
			gint size = 0;
			GdkPixbuf* _tmp35_ = NULL;
			gint _tmp36_ = 0;
			gint _tmp37_ = 0;
			GdkPixbuf* _tmp38_ = NULL;
			gint _tmp39_ = 0;
			gint _tmp40_ = 0;
			gint _tmp41_ = 0;
			GtkIconInfo* icon_info = NULL;
			GtkIconTheme* _tmp42_ = NULL;
			GEmblemedIcon* _tmp43_ = NULL;
			gint _tmp44_ = 0;
			GtkIconInfo* _tmp45_ = NULL;
			GdkPixbuf* _tmp46_ = NULL;
			GtkIconInfo* _tmp47_ = NULL;
			GdkPixbuf* _tmp48_ = NULL;
			GdkPixbuf* _tmp49_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp35_ = pixbuf;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp36_ = gdk_pixbuf_get_width (_tmp35_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp37_ = _tmp36_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp38_ = pixbuf;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp39_ = gdk_pixbuf_get_height (_tmp38_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp40_ = _tmp39_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp41_ = MAX (_tmp37_, _tmp40_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			size = _tmp41_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp42_ = theme;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp43_ = emblemed_icon;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp44_ = size;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp45_ = gtk_icon_theme_lookup_by_gicon (_tmp42_, (GIcon*) _tmp43_, _tmp44_, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			icon_info = _tmp45_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp47_ = icon_info;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp48_ = gtk_icon_info_load_icon (_tmp47_, &_inner_error_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp46_ = _tmp48_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_gtk_icon_info_free0 (icon_info);
#line 832 "collection-view.c"
				goto __catch5_g_error;
			}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp49_ = _tmp46_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp46_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			pixbuf = _tmp49_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (_tmp46_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_gtk_icon_info_free0 (icon_info);
#line 847 "collection-view.c"
		}
		goto __finally5;
		__catch5_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp50_ = NULL;
			const gchar* _tmp51_ = NULL;
			gchar* _tmp52_ = NULL;
			gchar* _tmp53_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_error_ = _inner_error_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_inner_error_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp50_ = _error_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp51_ = _tmp50_->message;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp52_ = g_strconcat ("Unable to render the emblem: ", _tmp51_, NULL);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp53_ = _tmp52_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_warning ("collection-view.vala:78: %s", _tmp53_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_free0 (_tmp53_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_error_free0 (_error_);
#line 875 "collection-view.c"
		}
		__finally5:
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (theme);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (emblemed_icon);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (machine);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_clear_error (&_inner_error_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return;
#line 898 "collection-view.c"
		}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (theme);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (emblemed_icon);
#line 904 "collection-view.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp54_ = self->priv->store;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp55_ = *iter;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp56_ = pixbuf;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp54_, &_tmp55_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, _tmp56_, -1);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (pixbuf);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (machine);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 924 "collection-view.c"
}


static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self) {
	GtkTreeIter* dup;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return dup;
#line 936 "collection-view.c"
}


static gpointer __gtk_tree_iter_dup0 (gpointer self) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 943 "collection-view.c"
}


static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	BoxesCollectionItem* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GtkListStore* _tmp7_ = NULL;
	GtkTreeIter _tmp8_ = {0};
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	GtkListStore* _tmp14_ = NULL;
	GtkTreeIter _tmp15_ = {0};
	GtkListStore* _tmp16_ = NULL;
	GtkTreeIter _tmp17_ = {0};
	BoxesCollectionItem* _tmp18_ = NULL;
	GtkTreeIter _tmp19_ = {0};
	BoxesCollectionItem* _tmp20_ = NULL;
	GtkTreeIter _tmp21_ = {0};
	GtkTreeIter* _tmp22_ = NULL;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (title != NULL);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp1_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->store;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = item;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = g_strdup_printf ("%p", _tmp4_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, GD_MAIN_COLUMN_ID, _tmp6_, -1);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (_tmp6_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->store;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = iter;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = title;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp7_, &_tmp8_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp9_, -1);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = info;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp10_ != NULL) {
#line 1007 "collection-view.c"
		GtkListStore* _tmp11_ = NULL;
		GtkTreeIter _tmp12_ = {0};
		const gchar* _tmp13_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = self->priv->store;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp12_ = iter;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp13_ = info;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp11_, &_tmp12_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp13_, -1);
#line 1019 "collection-view.c"
	}
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->priv->store;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = iter;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp14_, &_tmp15_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, FALSE, -1);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = self->priv->store;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = iter;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp16_, &_tmp17_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, _tmp18_, -1);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = iter;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp19_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = iter;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = __gtk_tree_iter_dup0 (&_tmp21_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp20_, "iter", _tmp22_, g_free);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	*result = iter;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return;
#line 1051 "collection-view.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data10_;
#line 1060 "collection-view.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 1069 "collection-view.c"
		BoxesCollectionView* self;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data10_->self;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data10_->machine);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data10_->item);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block10Data, _data10_);
#line 1081 "collection-view.c"
	}
}


static void __lambda68_ (Block10Data* _data10_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data10_->iter;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1095 "collection-view.c"
}


static void ___lambda68__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda68_ (self);
#line 1102 "collection-view.c"
}


static void __lambda69_ (Block10Data* _data10_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data10_->iter;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1115 "collection-view.c"
}


static void ___lambda69__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda69_ (self);
#line 1122 "collection-view.c"
}


static void __lambda70_ (Block10Data* _data10_) {
	BoxesCollectionView* self;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	BoxesCollectionItem* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data10_->iter;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data10_->item;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_collection_item_get_name (_tmp2_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp4_, -1);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1149 "collection-view.c"
}


static void ___lambda70__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda70_ (self);
#line 1156 "collection-view.c"
}


static void __lambda71_ (Block10Data* _data10_) {
	BoxesCollectionView* self;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	BoxesMachine* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data10_->iter;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data10_->machine;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_machine_get_info (_tmp2_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp4_, -1);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1183 "collection-view.c"
}


static void ___lambda71__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda71_ (self);
#line 1190 "collection-view.c"
}


static void __lambda73_ (Block10Data* _data10_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
	BoxesMachine* _tmp1_ = NULL;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data10_->self;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data10_->iter;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data10_->machine;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_activity (self, &_tmp0_, _tmp1_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1208 "collection-view.c"
}


static void ___lambda73__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda73_ (self);
#line 1215 "collection-view.c"
}


void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	Block10Data* _data10_;
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	BoxesMachine* _tmp4_ = NULL;
	BoxesMachine* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	BoxesMachine* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	BoxesCollectionItem* _tmp13_ = NULL;
	GtkTreeIter _tmp14_ = {0};
	gulong pixbuf_id = 0UL;
	BoxesMachine* _tmp15_ = NULL;
	gulong _tmp16_ = 0UL;
	BoxesCollectionItem* _tmp17_ = NULL;
	gulong _tmp18_ = 0UL;
	gulong categories_id = 0UL;
	BoxesMachine* _tmp19_ = NULL;
	BoxesBoxConfig* _tmp20_ = NULL;
	gulong _tmp21_ = 0UL;
	BoxesCollectionItem* _tmp22_ = NULL;
	gulong _tmp23_ = 0UL;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp24_ = NULL;
	gulong _tmp25_ = 0UL;
	BoxesCollectionItem* _tmp26_ = NULL;
	gulong _tmp27_ = 0UL;
	gulong info_id = 0UL;
	BoxesMachine* _tmp28_ = NULL;
	gulong _tmp29_ = 0UL;
	BoxesCollectionItem* _tmp30_ = NULL;
	gulong _tmp31_ = 0UL;
	GtkTreeIter _tmp32_ = {0};
	BoxesMachine* _tmp33_ = NULL;
	gulong under_construct_id = 0UL;
	BoxesMachine* _tmp34_ = NULL;
	gulong _tmp35_ = 0UL;
	BoxesCollectionItem* _tmp36_ = NULL;
	gulong _tmp37_ = 0UL;
	BoxesCollectionItem* _tmp38_ = NULL;
	BoxesApp* _tmp39_ = NULL;
	BoxesUIState _tmp40_ = 0;
	BoxesUIState _tmp41_ = 0;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_ = g_slice_new0 (Block10Data);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->_ref_count_ = 1;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->self = g_object_ref (self);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data10_->item);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->item = _tmp1_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data10_->item;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->machine = _tmp3_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data10_->machine;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ == NULL) {
#line 1294 "collection-view.c"
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = g_strdup_printf ("Cannot add item %p", &_data10_->item);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_warning ("collection-view.vala:109: %s", _tmp6_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (_tmp6_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block10_data_unref (_data10_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data10_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1311 "collection-view.c"
	}
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data10_->machine;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp7_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = _data10_->machine;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = boxes_machine_get_info (_tmp10_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = _tmp11_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _data10_->item;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_append (self, _tmp9_, _tmp12_, _tmp13_, &_tmp14_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_->iter = _tmp14_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _data10_->machine;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = g_signal_connect_data ((GObject*) _tmp15_, "notify::pixbuf", (GCallback) ___lambda68__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = _tmp16_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = _data10_->item;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = pixbuf_id;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp17_, "pixbuf_id", (gpointer) ((guintptr) _tmp18_), NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = _data10_->machine;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = _tmp19_->config;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = g_signal_connect_data ((GObject*) _tmp20_, "notify::categories", (GCallback) ___lambda69__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	categories_id = _tmp21_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = _data10_->item;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = categories_id;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp22_, "categories_id", (gpointer) ((guintptr) _tmp23_), NULL);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = _data10_->item;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = g_signal_connect_data ((GObject*) _tmp24_, "notify::name", (GCallback) ___lambda70__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = _tmp25_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = _data10_->item;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp27_ = name_id;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp26_, "name_id", (gpointer) ((guintptr) _tmp27_), NULL);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp28_ = _data10_->machine;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp29_ = g_signal_connect_data ((GObject*) _tmp28_, "notify::info", (GCallback) ___lambda71__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = _tmp29_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp30_ = _data10_->item;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp31_ = info_id;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp30_, "info_id", (gpointer) ((guintptr) _tmp31_), NULL);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp32_ = _data10_->iter;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp33_ = _data10_->machine;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_activity (self, &_tmp32_, _tmp33_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp34_ = _data10_->machine;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp35_ = g_signal_connect_data ((GObject*) _tmp34_, "notify::under-construction", (GCallback) ___lambda73__g_object_notify, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	under_construct_id = _tmp35_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp36_ = _data10_->item;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp37_ = under_construct_id;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp36_, "under_construct_id", (gpointer) ((guintptr) _tmp37_), NULL);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp38_ = _data10_->item;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp39_ = boxes_app_app;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp40_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp39_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp41_ = _tmp40_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp38_, _tmp41_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block10_data_unref (_data10_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data10_ = NULL;
#line 1413 "collection-view.c"
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data11_;
#line 1422 "collection-view.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1429 "collection-view.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_free (self);
#line 1438 "collection-view.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 1447 "collection-view.c"
		BoxesCollectionView* self;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data11_->self;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		__g_list_free__g_object_unref0_0 (_data11_->selected);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block11Data, _data11_);
#line 1457 "collection-view.c"
	}
}


static gboolean __lambda74_ (Block11Data* _data11_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	gboolean is_selected = FALSE;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data11_->self;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (store != NULL, FALSE);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = store;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, &is_selected, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = is_selected;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_) {
#line 1489 "collection-view.c"
		BoxesCollectionItem* _tmp4_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp4_ != NULL;
#line 1495 "collection-view.c"
	} else {
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 1499 "collection-view.c"
	}
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_) {
#line 1503 "collection-view.c"
		BoxesCollectionItem* _tmp5_ = NULL;
		BoxesCollectionItem* _tmp6_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = item;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _g_object_ref0 (_tmp5_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data11_->selected = g_list_append (_data11_->selected, _tmp6_);
#line 1512 "collection-view.c"
	}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1520 "collection-view.c"
}


static gboolean ___lambda74__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda74_ (self, model, path, iter);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1529 "collection-view.c"
}


GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self) {
	GList* result = NULL;
	Block11Data* _data11_;
	GtkListStore* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->_ref_count_ = 1;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->self = g_object_ref (self);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->selected = NULL;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp0_, ___lambda74__gtk_tree_model_foreach_func, _data11_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data11_->selected;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_->selected = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp1_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block11_data_unref (_data11_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data11_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1564 "collection-view.c"
}


void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	GtkTreeIter* iter = NULL;
	BoxesCollectionItem* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_ = NULL;
	GtkTreeIter* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkTreeIter* _tmp5_ = NULL;
	GtkTreeIter _tmp6_ = {0};
	BoxesCollectionItem* _tmp7_ = NULL;
	gulong pixbuf_id = 0UL;
	BoxesCollectionItem* _tmp8_ = NULL;
	gconstpointer _tmp9_ = NULL;
	BoxesCollectionItem* _tmp10_ = NULL;
	gulong _tmp11_ = 0UL;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp12_ = NULL;
	gconstpointer _tmp13_ = NULL;
	BoxesCollectionItem* _tmp14_ = NULL;
	gulong _tmp15_ = 0UL;
	gulong info_id = 0UL;
	BoxesCollectionItem* _tmp16_ = NULL;
	gconstpointer _tmp17_ = NULL;
	BoxesCollectionItem* _tmp18_ = NULL;
	gulong _tmp19_ = 0UL;
	gulong under_construct_id = 0UL;
	BoxesCollectionItem* _tmp20_ = NULL;
	gconstpointer _tmp21_ = NULL;
	BoxesCollectionItem* _tmp22_ = NULL;
	gulong _tmp23_ = 0UL;
	BoxesCollectionItem* _tmp24_ = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_debug ("collection-view.vala:173: item not in view or already removed");
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1621 "collection-view.c"
	}
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = iter;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = *_tmp5_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_remove (_tmp4_, &_tmp6_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = item;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp7_, "iter", NULL, g_free);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = g_object_get_data ((GObject*) _tmp8_, "pixbuf_id");
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = (gulong) ((guintptr) _tmp9_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = item;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = pixbuf_id;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = item;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = g_object_get_data ((GObject*) _tmp12_, "name_id");
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = (gulong) ((guintptr) _tmp13_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = item;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = name_id;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp14_, _tmp15_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = item;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = g_object_get_data ((GObject*) _tmp16_, "info_id");
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = (gulong) ((guintptr) _tmp17_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = info_id;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp18_, _tmp19_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = g_object_get_data ((GObject*) _tmp20_, "under_construct_id");
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	under_construct_id = (gulong) ((guintptr) _tmp21_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = item;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = under_construct_id;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp22_, _tmp23_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = item;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp24_) : NULL) != NULL) {
#line 1687 "collection-view.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp25_ = NULL;
		BoxesMachine* _tmp26_ = NULL;
		gulong categories_id = 0UL;
		BoxesCollectionItem* _tmp27_ = NULL;
		gconstpointer _tmp28_ = NULL;
		BoxesMachine* _tmp29_ = NULL;
		BoxesBoxConfig* _tmp30_ = NULL;
		gulong _tmp31_ = 0UL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp25_ = item;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp25_) : NULL);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		machine = _tmp26_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = item;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp28_ = g_object_get_data ((GObject*) _tmp27_, "categories_id");
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		categories_id = (gulong) ((guintptr) _tmp28_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp29_ = machine;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp30_ = _tmp29_->config;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp31_ = categories_id;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_signal_handler_disconnect ((GObject*) _tmp30_, _tmp31_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (machine);
#line 1719 "collection-view.c"
	}
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 1723 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* result = NULL;
	GValue value = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	BoxesCollectionItem* _tmp4_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_value ((GtkTreeModel*) _tmp0_, &_tmp1_, (gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &_tmp2_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	value = _tmp2_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = value;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (g_value_get_object (&_tmp3_));
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp4_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1759 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path) {
	BoxesCollectionItem* result = NULL;
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
	GtkTreeIter _tmp5_ = {0};
	GtkTreeIter _tmp6_ = {0};
	BoxesCollectionItem* _tmp7_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = path;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp2_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->model_filter;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = filter_iter;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp5_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = iter;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_collection_view_get_item_for_iter (self, &_tmp6_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp7_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1803 "collection-view.c"
}


static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter) {
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	GtkTreeIter _tmp0_ = {0};
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
	BoxesCollectionFilter* _tmp4_ = NULL;
	BoxesCollectionItem* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = *iter;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_iter (self, &_tmp0_);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = item;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ == NULL) {
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 1839 "collection-view.c"
	}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_->filter;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = boxes_collection_filter_filter (_tmp4_, _tmp5_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp6_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1855 "collection-view.c"
}


void boxes_collection_view_refilter (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_refilter (_tmp0_);
#line 1867 "collection-view.c"
}


void boxes_collection_view_activate_first_item (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = gtk_tree_model_iter_n_children ((GtkTreeModel*) _tmp0_, NULL);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == 1) {
#line 1882 "collection-view.c"
		GtkTreePath* path = NULL;
		GtkTreePath* _tmp2_ = NULL;
		GtkWidget* _tmp3_ = NULL;
		GtkTreePath* _tmp4_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = gtk_tree_path_new_from_string ("0");
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		path = _tmp2_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = path;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_icon_view_item_activated (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GTK_TYPE_ICON_VIEW) ? ((GtkIconView*) _tmp3_) : NULL, _tmp4_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 1899 "collection-view.c"
	}
}


static gint __lambda75_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreeIter* a, GtkTreeIter* b) {
	gint result = 0;
	BoxesCollectionItem* item_a = NULL;
	BoxesCollectionItem* item_b = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkTreeModel* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	gboolean _tmp4_ = FALSE;
	BoxesCollectionItem* _tmp5_ = NULL;
	BoxesCollectionItem* _tmp7_ = NULL;
	BoxesCollectionItem* _tmp8_ = NULL;
	gint _tmp9_ = 0;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (store != NULL, 0);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = store;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *a;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_a, -1);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = store;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = *b;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp2_, &_tmp3_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_b, -1);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item_a;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ == NULL) {
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = TRUE;
#line 1941 "collection-view.c"
	} else {
		BoxesCollectionItem* _tmp6_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = item_b;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp6_ == NULL;
#line 1948 "collection-view.c"
	}
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_) {
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = 0;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_b);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_a);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 1960 "collection-view.c"
	}
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = item_a;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item_b;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = boxes_collection_item_compare (_tmp7_, _tmp8_);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp9_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_b);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_a);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1976 "collection-view.c"
}


static gint ___lambda75__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self) {
	gint result;
	result = __lambda75_ ((BoxesCollectionView*) self, model, a, b);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1985 "collection-view.c"
}


static void __lambda76_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 1995 "collection-view.c"
}


static void ___lambda76__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self) {
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda76_ ((BoxesCollectionView*) self);
#line 2002 "collection-view.c"
}


static void __lambda77_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2012 "collection-view.c"
}


static void ___lambda77__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda77_ ((BoxesCollectionView*) self);
#line 2019 "collection-view.c"
}


static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = boxes_collection_view_model_visible ((BoxesCollectionView*) self, model, iter);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2028 "collection-view.c"
}


static void __lambda78_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path) {
	BoxesCollectionItem* item = NULL;
	GtkTreePath* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesApp* _tmp7_ = NULL;
	BoxesCollectionItem* _tmp8_ = NULL;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (view != NULL);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (id != NULL);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (path != NULL);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = path;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_path (self, _tmp0_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 2056 "collection-view.c"
		BoxesCollectionItem* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gboolean _tmp6_ = FALSE;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = boxes_libvirt_machine_get_importing (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp4_) : NULL);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp6_;
#line 2068 "collection-view.c"
	} else {
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 2072 "collection-view.c"
	}
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_) {
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 2080 "collection-view.c"
	}
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_app_app;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_select_item (_tmp7_, _tmp8_);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 2090 "collection-view.c"
}


static void ___lambda78__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self) {
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda78_ ((BoxesCollectionView*) self, _sender, object, p0);
#line 2097 "collection-view.c"
}


static void __lambda79_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2109 "collection-view.c"
}


static void ___lambda79__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self) {
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda79_ ((BoxesCollectionView*) self);
#line 2116 "collection-view.c"
}


static void __lambda80_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_set_selection_mode (_tmp0_, TRUE);
#line 2126 "collection-view.c"
}


static void ___lambda80__gd_main_view_selection_mode_request (GdMainView* _sender, gpointer self) {
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda80_ ((BoxesCollectionView*) self);
#line 2133 "collection-view.c"
}


static gboolean _boxes_collection_view_on_motion_notify_gtk_widget_motion_notify_event (GtkWidget* _sender, GdkEventMotion* event, gpointer self) {
	gboolean result;
	result = boxes_collection_view_on_motion_notify ((BoxesCollectionView*) self, _sender, event);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2142 "collection-view.c"
}


static gboolean _boxes_collection_view_on_leave_notify_gtk_widget_leave_notify_event (GtkWidget* _sender, GdkEventCrossing* event, gpointer self) {
	gboolean result;
	result = boxes_collection_view_on_leave_notify ((BoxesCollectionView*) self, _sender, event);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2151 "collection-view.c"
}


static void boxes_collection_view_setup_view (BoxesCollectionView* self) {
	GtkListStore* _tmp0_ = NULL;
	GtkListStore* _tmp1_ = NULL;
	GtkListStore* _tmp2_ = NULL;
	GtkListStore* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkListStore* _tmp5_ = NULL;
	GtkTreeModelFilter* _tmp6_ = NULL;
	GtkTreeModelFilter* _tmp7_ = NULL;
	GtkTreeModelFilter* _tmp8_ = NULL;
	GtkStyleContext* _tmp9_ = NULL;
	GtkIconView* icon_view = NULL;
	GtkWidget* _tmp10_ = NULL;
	GtkIconView* _tmp11_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = gtk_list_store_new ((gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_LONG, G_TYPE_BOOLEAN, G_TYPE_UINT, BOXES_TYPE_COLLECTION_ITEM);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->store);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->store = _tmp0_;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->store;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_default_sort_func ((GtkTreeSortable*) _tmp1_, ___lambda75__gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->store;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp2_, GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->store;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp3_, "row-deleted", (GCallback) ___lambda76__gtk_tree_model_row_deleted, self, 0);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp4_, "row-inserted", (GCallback) ___lambda77__gtk_tree_model_row_inserted, self, 0);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->priv->store;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp5_, NULL);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->model_filter = _tmp6_;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->model_filter;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_set_visible_func (_tmp7_, _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func, g_object_ref (self), g_object_unref);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_view_type ((GdMainView*) self, GD_MAIN_VIEW_ICON);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = self->priv->model_filter;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_model ((GdMainView*) self, (GtkTreeModel*) _tmp8_);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp9_, "boxes-icon-view");
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "item-activated", (GCallback) ___lambda78__gd_main_view_item_activated, self, 0);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "view-selection-changed", (GCallback) ___lambda79__gd_main_view_view_selection_changed, self, 0);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "selection-mode-request", (GCallback) ___lambda80__gd_main_view_selection_mode_request, self, 0);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GTK_TYPE_ICON_VIEW) ? ((GtkIconView*) _tmp10_) : NULL);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	icon_view = _tmp11_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_add_events ((GtkWidget*) icon_view, (gint) GDK_LEAVE_NOTIFY_MASK);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkWidget*) icon_view, "motion-notify-event", (GCallback) _boxes_collection_view_on_motion_notify_gtk_widget_motion_notify_event, self, 0);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkWidget*) icon_view, "leave-notify-event", (GCallback) _boxes_collection_view_on_leave_notify_gtk_widget_leave_notify_event, self, 0);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (icon_view);
#line 2237 "collection-view.c"
}


static Block12Data* block12_data_ref (Block12Data* _data12_) {
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data12_;
#line 2246 "collection-view.c"
}


static void block12_data_unref (void * _userdata_) {
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 2255 "collection-view.c"
		BoxesCollectionView* self;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data12_->self;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block12Data, _data12_);
#line 2263 "collection-view.c"
	}
}


static gboolean __lambda82_ (Block12Data* _data12_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkTreeIter _tmp2_ = {0};
	gboolean selected = FALSE;
	BoxesSelectionCriteria _tmp3_ = 0;
	GtkListStore* _tmp12_ = NULL;
	GtkTreeIter _tmp13_ = {0};
	gboolean _tmp14_ = FALSE;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data12_->self;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_model != NULL, FALSE);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_path != NULL, FALSE);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_iter != NULL, FALSE);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *filter_iter;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp0_, &_tmp2_, &_tmp1_);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _data12_->selection;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (_tmp3_) {
#line 2300 "collection-view.c"
		default:
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_ALL:
#line 2304 "collection-view.c"
		{
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = TRUE;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2310 "collection-view.c"
		}
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_NONE:
#line 2314 "collection-view.c"
		{
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = FALSE;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2320 "collection-view.c"
		}
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_RUNNING:
#line 2324 "collection-view.c"
		{
			BoxesCollectionItem* item = NULL;
			GtkListStore* _tmp4_ = NULL;
			GtkTreeIter _tmp5_ = {0};
			gboolean _tmp6_ = FALSE;
			gboolean _tmp7_ = FALSE;
			BoxesCollectionItem* _tmp8_ = NULL;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp4_ = self->priv->store;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp5_ = iter;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp8_ = item;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp8_ != NULL) {
#line 2342 "collection-view.c"
				BoxesCollectionItem* _tmp9_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp9_ = item;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_MACHINE);
#line 2348 "collection-view.c"
			} else {
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = FALSE;
#line 2352 "collection-view.c"
			}
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp7_) {
#line 2356 "collection-view.c"
				BoxesCollectionItem* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp10_ = item;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp11_ = boxes_machine_is_running (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = _tmp11_;
#line 2365 "collection-view.c"
			} else {
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = FALSE;
#line 2369 "collection-view.c"
			}
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = _tmp6_;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2377 "collection-view.c"
		}
	}
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = self->priv->store;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = iter;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = selected;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp12_, &_tmp13_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, _tmp14_, -1);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2392 "collection-view.c"
}


static gboolean ___lambda82__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda82_ (self, model, path, iter);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2401 "collection-view.c"
}


void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection) {
	Block12Data* _data12_;
	BoxesSelectionCriteria _tmp0_ = 0;
	BoxesApp* _tmp1_ = NULL;
	GtkTreeModelFilter* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->_ref_count_ = 1;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->self = g_object_ref (self);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = selection;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_->selection = _tmp0_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_app;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_set_selection_mode (_tmp1_, TRUE);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model_filter;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp2_, ___lambda82__gtk_tree_model_foreach_func, _data12_);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp3_, "selected-items");
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block12_data_unref (_data12_);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data12_ = NULL;
#line 2441 "collection-view.c"
}


static Block13Data* block13_data_ref (Block13Data* _data13_) {
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data13_->_ref_count_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data13_;
#line 2450 "collection-view.c"
}


static void block13_data_unref (void * _userdata_) {
	Block13Data* _data13_;
	_data13_ = (Block13Data*) _userdata_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data13_->_ref_count_)) {
#line 2459 "collection-view.c"
		BoxesCollectionView* self;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data13_->self;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data13_->machine);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block13Data, _data13_);
#line 2469 "collection-view.c"
	}
}


static gboolean __lambda72_ (Block13Data* _data13_) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	GtkTreeIter* machine_iter = NULL;
	BoxesMachine* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_ = NULL;
	GtkTreeIter* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkTreeIter* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	GtkTreeIter _tmp7_ = {0};
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data13_->self;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data13_->machine;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine_iter = _tmp2_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = machine_iter;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (machine_iter);
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2506 "collection-view.c"
	}
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine_iter;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _data13_->pulse;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->pulse = _tmp6_ + 1;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = *_tmp5_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp4_, &_tmp7_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, _tmp6_, -1);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = TRUE;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (machine_iter);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2528 "collection-view.c"
}


static gboolean ___lambda72__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda72_ (self);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2537 "collection-view.c"
}


static void boxes_collection_view_setup_activity (BoxesCollectionView* self, GtkTreeIter* iter, BoxesMachine* machine) {
	Block13Data* _data13_;
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	guint activity_timeout = 0U;
	BoxesMachine* _tmp2_ = NULL;
	gconstpointer _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	BoxesMachine* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	GtkListStore* _tmp12_ = NULL;
	GtkTreeIter _tmp13_ = {0};
	gint _tmp14_ = 0;
	guint _tmp15_ = 0U;
	BoxesMachine* _tmp16_ = NULL;
	guint _tmp17_ = 0U;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (machine != NULL);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_ = g_slice_new0 (Block13Data);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->_ref_count_ = 1;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->self = g_object_ref (self);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = machine;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data13_->machine);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->machine = _tmp1_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data13_->machine;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "activity_timeout");
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	activity_timeout = (guint) ((guintptr) _tmp3_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = activity_timeout;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ > ((guint) 0)) {
#line 2588 "collection-view.c"
		guint _tmp5_ = 0U;
		BoxesMachine* _tmp6_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = activity_timeout;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_source_remove (_tmp5_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _data13_->machine;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_object_set_data_full ((GObject*) _tmp6_, "activity_timeout", (gpointer) ((guintptr) ((guint) 0)), NULL);
#line 2599 "collection-view.c"
	}
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data13_->machine;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_machine_get_under_construction (_tmp7_);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp9_) {
#line 2609 "collection-view.c"
		GtkListStore* _tmp10_ = NULL;
		GtkTreeIter _tmp11_ = {0};
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp10_ = self->priv->store;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = *iter;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp10_, &_tmp11_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, 0, -1);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block13_data_unref (_data13_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data13_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 2624 "collection-view.c"
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->pulse = 1;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = self->priv->store;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = *iter;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = _data13_->pulse;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_->pulse = _tmp14_ + 1;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp12_, &_tmp13_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, _tmp14_, -1);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 150, ___lambda72__gsource_func, block13_data_ref (_data13_), block13_data_unref);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	activity_timeout = _tmp15_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = _data13_->machine;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = activity_timeout;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp16_, "activity_timeout", (gpointer) ((guintptr) _tmp17_), NULL);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block13_data_unref (_data13_);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data13_ = NULL;
#line 2652 "collection-view.c"
}


static GdkEventMotion* _vala_GdkEventMotion_copy (GdkEventMotion* self) {
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return g_boxed_copy (gdk_event_get_type (), self);
#line 2659 "collection-view.c"
}


static gpointer __vala_GdkEventMotion_copy0 (gpointer self) {
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? _vala_GdkEventMotion_copy (self) : NULL;
#line 2666 "collection-view.c"
}


static gpointer _gtk_tree_path_copy0 (gpointer self) {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? gtk_tree_path_copy (self) : NULL;
#line 2673 "collection-view.c"
}


static gboolean __lambda81_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter) {
	gboolean result = FALSE;
	GtkTreeIter _tmp0_ = {0};
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (store != NULL, FALSE);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = *iter;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2694 "collection-view.c"
}


static gboolean ___lambda81__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda81_ ((BoxesCollectionView*) self, model, path, iter);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2703 "collection-view.c"
}


static void _vala_GdkEventMotion_free (GdkEventMotion* self) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_boxed_free (gdk_event_get_type (), self);
#line 2710 "collection-view.c"
}


static gboolean boxes_collection_view_on_motion_notify (BoxesCollectionView* self, GtkWidget* widget, GdkEvent* event) {
	gboolean result = FALSE;
	GtkIconView* icon_view = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkIconView* _tmp1_ = NULL;
	GdkEventMotion* motion = NULL;
	GdkEvent* _tmp2_ = NULL;
	GdkEventMotion* _tmp3_ = NULL;
	gint x = 0;
	gint y = 0;
	GtkIconView* _tmp4_ = NULL;
	GdkEventMotion* _tmp5_ = NULL;
	gdouble _tmp6_ = 0.0;
	GdkEventMotion* _tmp7_ = NULL;
	gdouble _tmp8_ = 0.0;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
	GtkTreePath* path = NULL;
	GtkIconView* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint _tmp13_ = 0;
	GtkTreePath* _tmp14_ = NULL;
	GtkTreePath* _tmp15_ = NULL;
	GtkTreePath* _tmp16_ = NULL;
	GtkListStore* _tmp25_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = widget;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GTK_TYPE_ICON_VIEW) ? ((GtkIconView*) _tmp0_) : NULL);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	icon_view = _tmp1_;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = event;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = __vala_GdkEventMotion_copy0 ((GdkEventMotion*) _tmp2_);
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	motion = _tmp3_;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = icon_view;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = motion;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_->x;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = motion;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _tmp7_->y;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_icon_view_convert_widget_to_bin_window_coords (_tmp4_, (gint) _tmp6_, (gint) _tmp8_, &_tmp9_, &_tmp10_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	x = _tmp9_;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	y = _tmp10_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = icon_view;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = x;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = y;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = gtk_icon_view_get_path_at_pos (_tmp11_, _tmp12_, _tmp13_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _gtk_tree_path_copy0 (_tmp14_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	path = _tmp15_;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = path;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp16_ != NULL) {
#line 2789 "collection-view.c"
		GtkTreeIter filter_iter = {0};
		GtkTreeModelFilter* _tmp17_ = NULL;
		GtkTreePath* _tmp18_ = NULL;
		GtkTreeIter _tmp19_ = {0};
		GtkTreeModelFilter* _tmp20_ = NULL;
		GtkTreeIter _tmp21_ = {0};
		GtkTreeIter _tmp22_ = {0};
		GtkTreeIter _tmp23_ = {0};
		GtkTreeIter* _tmp24_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp17_ = self->priv->model_filter;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp18_ = path;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_tree_model_get_iter ((GtkTreeModel*) _tmp17_, &_tmp19_, _tmp18_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		filter_iter = _tmp19_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp20_ = self->priv->model_filter;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21_ = filter_iter;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_tree_model_filter_convert_iter_to_child_iter (_tmp20_, &_tmp22_, &_tmp21_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (self->priv->prelight_iter);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp23_ = _tmp22_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp24_ = __gtk_tree_iter_dup0 (&_tmp23_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self->priv->prelight_iter = _tmp24_;
#line 2821 "collection-view.c"
	} else {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (self->priv->prelight_iter);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self->priv->prelight_iter = NULL;
#line 2827 "collection-view.c"
	}
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = self->priv->store;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp25_, ___lambda81__gtk_tree_model_foreach_func, self);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__vala_GdkEventMotion_free0 (motion);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (icon_view);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2843 "collection-view.c"
}


static gboolean boxes_collection_view_on_leave_notify (BoxesCollectionView* self, GtkWidget* widget, GdkEvent* event) {
	gboolean result = FALSE;
	GtkTreeIter* _tmp0_ = NULL;
	GtkTreeIter* iter = NULL;
	GtkTreeIter* _tmp1_ = NULL;
	GtkTreeIter* _tmp2_ = NULL;
	GtkTreeIter* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->prelight_iter;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp0_ == NULL) {
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2869 "collection-view.c"
	}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->prelight_iter;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 (_tmp1_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (self->priv->prelight_iter);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->prelight_iter = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = *_tmp3_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp4_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2893 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_construct (GType object_type) {
	BoxesCollectionView * self = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) g_object_new (object_type, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self;
#line 2903 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_new (void) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return boxes_collection_view_construct (BOXES_TYPE_COLLECTION_VIEW);
#line 2910 "collection-view.c"
}


static BoxesUIState boxes_collection_view_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2926 "collection-view.c"
}


static void boxes_collection_view_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 2941 "collection-view.c"
}


static BoxesUIState boxes_collection_view_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_ui_state;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2957 "collection-view.c"
}


static void boxes_collection_view_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_ui_state = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 2972 "collection-view.c"
}


BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self) {
	BoxesCategory* result;
	BoxesCategory* _tmp0_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_category;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2987 "collection-view.c"
}


void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value) {
	BoxesCategory* _tmp0_ = NULL;
	BoxesCategory* _tmp1_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_category = _tmp1_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "category");
#line 3006 "collection-view.c"
}


static void _boxes_collection_view_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_ui_state_changed ((BoxesCollectionView*) self);
#line 3013 "collection-view.c"
}


static void _boxes_collection_view___lambda83_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	BoxesApp* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_get_selection_mode (_tmp0_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_selection_mode ((GdMainView*) self, _tmp2_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_app_get_selection_mode (_tmp3_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = _tmp4_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp5_) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all ((GdMainView*) self);
#line 3042 "collection-view.c"
	}
}


static void __boxes_collection_view___lambda83__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_boxes_collection_view___lambda83_ ((BoxesCollectionView*) self);
#line 3050 "collection-view.c"
}


static GObject * boxes_collection_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesCollectionView * self;
	const gchar* _tmp0_ = NULL;
	BoxesCategory* _tmp1_ = NULL;
	BoxesCategory* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	parent_class = G_OBJECT_CLASS (boxes_collection_view_parent_class);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _ ("New and Recent");
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_category_new (_tmp0_, BOXES_CATEGORY_KIND_NEW);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_set_category (self, _tmp2_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_tmp2_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_view (self);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_collection_view_ui_state_changed_g_object_notify, self, 0);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::selection-mode", (GCallback) __boxes_collection_view___lambda83__g_object_notify, self, 0);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return obj;
#line 3088 "collection-view.c"
}


static void boxes_collection_view_class_init (BoxesCollectionViewClass * klass) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionViewPrivate));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_collection_view_get_property;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_collection_view_set_property;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_collection_view_constructor;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_view_finalize;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_CATEGORY, g_param_spec_object ("category", "category", "category", BOXES_TYPE_CATEGORY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3111 "collection-view.c"
}


static void boxes_collection_view_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->get_previous_ui_state = boxes_collection_view_real_get_previous_ui_state;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->set_previous_ui_state = boxes_collection_view_real_set_previous_ui_state;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->get_ui_state = boxes_collection_view_real_get_ui_state;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->set_ui_state = boxes_collection_view_real_set_ui_state;
#line 3126 "collection-view.c"
}


static void boxes_collection_view_instance_init (BoxesCollectionView * self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv = BOXES_COLLECTION_VIEW_GET_PRIVATE (self);
#line 3133 "collection-view.c"
}


static void boxes_collection_view_finalize (GObject* obj) {
	BoxesCollectionView * self;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->store);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (self->priv->prelight_iter);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (boxes_collection_view_parent_class)->finalize (obj);
#line 3151 "collection-view.c"
}


GType boxes_collection_view_get_type (void) {
	static volatile gsize boxes_collection_view_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionView), 0, (GInstanceInitFunc) boxes_collection_view_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_collection_view_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_collection_view_type_id;
		boxes_collection_view_type_id = g_type_register_static (gd_main_view_get_type (), "BoxesCollectionView", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_collection_view_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_collection_view_type_id__volatile, boxes_collection_view_type_id);
	}
	return boxes_collection_view_type_id__volatile;
}


static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_object (value, boxes_collection_view_get_category (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3192 "collection-view.c"
		default:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3198 "collection-view.c"
	}
}


static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_set_category (self, g_value_get_object (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3226 "collection-view.c"
		default:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3232 "collection-view.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



